<?php

namespace Drupal\file_downloader\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\file_downloader\DownloadOptionPluginCollection;

/**
 * Defines the Download option config entity.
 *
 * @ConfigEntityType(
 *   id = "download_option_config",
 *   label = @Translation("Download option config"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\file_downloader\DownloadOptionConfigListBuilder",
 *     "form" = {
 *       "add" = "Drupal\file_downloader\Form\DownloadOptionConfigForm",
 *       "edit" = "Drupal\file_downloader\Form\DownloadOptionConfigForm",
 *       "delete" = "Drupal\file_downloader\Form\DownloadOptionConfigDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\file_downloader\DownloadOptionConfigHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "download_option_config",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "canonical" = "/admin/structure/download_option_config/{download_option_config}",
 *     "add-form" = "/admin/structure/download_option_config/add",
 *     "edit-form" = "/admin/structure/download_option_config/{download_option_config}/edit",
 *     "delete-form" = "/admin/structure/download_option_config/{download_option_config}/delete",
 *     "collection" = "/admin/structure/download_option_config"
 *   }
 * )
 */
class DownloadOptionConfig extends ConfigEntityBase implements DownloadOptionConfigInterface {

  /**
   * The Download option config ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The Download option config label.
   *
   * @var string
   */
  protected $label;

  /**
   * The id of the selected plugin.
   *
   * @var string
   */
  protected $plugin_id;

  /**
   * String containing $extensions
   *
   * @var string
   */
  protected $extensions;

  /**
   * The plugin instance settings.
   *
   * @var array
   */
  protected $settings = [];


  /**
   * {@inheritdoc}
   */
  public function getPlugin() {
    if (isset($this->plugin_id)) {
      return \Drupal::service('plugin.manager.download_option')->getPluginCollection($this)->get($this->plugin_id);
    }
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getPluginId() {
    return $this->plugin_id;
  }

  /**
   * {@inheritdoc}
   */
  public function getExtensions() {
    return $this->extensions;
  }
}
